@@ -19,8 +19,11 @@ def isConnected():
 
 
 def 帮助():
+    print(logs.颜色(
+        "由于termux存在一些问题，所以easygui无法使用而且matplotlib中文辅助模块要使用jupyter notebook才可以使用，这里就不上相关教程了",
+        色选="红色"))
     if isConnected():
-        print(logs.系统日志("Fishconsole 检查更新开始。。。"))
+        print(logs.系统日志(f"Fishconsole{fcv.version()} 检查更新开始。。。"))
         v = fcv.version()
         url = "https://pypi.org/project/Fishconsole/"
         res = requests.get(url).text
@@ -28,21 +31,21 @@ def 帮助():
         res_v = res_html.xpath("/html/body/main/div[2]/div/div[1]/h1/text()")[0]
         res_v = str(res_v[21:27])
         if res_v != v:
-            print(logs.系统日志("Fishconsole 检查更新结束"))
+            print(logs.系统日志(f"Fishconsole{fcv.version()} 检查更新结束"))
             print(logs.系统日志(f"检测到最新版本号发生了变化({res_v}>{v})，请在终端键入pip install --upgrade Fishconsole更新至最新版本"))
-        print(logs.系统日志("Fishconsole 检查更新结束"))
+        print(logs.系统日志(f"Fishconsole{fcv.version()} 检查更新结束"))
     else:
-        print(logs.系统日志("Fishconsole 检查更新结束"))
+        print(logs.系统日志(f"Fishconsole{fcv.version()} 检查更新结束"))
         print(logs.系统日志("你的设备没有联网，请检查网络连接"))
 
     print("如果您使用termux安装的话，请按1，否则按2")
     help_mod = input()
     if help_mod == "1":
-        print(logs.颜色(
-            "\n\n\n\n\n\n\n\n\n\n\n\n\n\n由于termux存在一些问题，所以easygui无法使用而且matplotlib中文辅助模块要使用jupyter notebook才可以使用，这里就不上相关教程了",
-            色选="红色"))
-        logs.分割线("这是logs模块的", "Fishconsole帮助文档")
+
+
+
         print(
+            f"logs.分割线('这是logs模块的', 'Fishconsole{fcv.version()}帮助文档'\n)"
             "你是不是不知道怎么用的？那就让我来告诉你吧!!\n"
             "这个函数是一个输出工具的集合，是由鱼鱼有几斤整理的\n"
             "我整理了这几个项目\n"
@@ -56,13 +59,11 @@ def 帮助():
             " (注意哦,分割线和日志都是可以和颜色叠加使用的)\n"
             "---------------------\n"
             "‘分割线’的语法是:\n"
-            "logs.分割线(输出显示文字,s模式='项目名')\n"
+            "logs.分割线(标题,文本,颜色选择)\n"
             "‘日志’的语法是:\n"
-            "logs.日志(输出显示文字)\n"
+            "logs.日志(显示文字,颜色选择)\n"
             "‘颜色’的语法是:\n"
-            "logs.颜色(输出显示文字)\n"
-            "示例（可以这种方法套）"
-            "print(logs.颜色(logs.分割线('帮助文档',s模式='🦈Fishconsole'),色选='蓝色'))\n"
+            "logs.颜色(输出显示文字,颜色选择)\n"
             "---------------------\n"
         )
         exit()
@@ -73,7 +74,7 @@ def 帮助():
         if res is not None:
             for a in res:
                 if a == "logs控制台输出辅助模块":
-                    logs.分割线("这是logs模块的", "Fishconsole帮助文档")
+                    print(logs.分割线("这是logs模块的", f"Fishconsole{fcv.version()} 帮助文档","红色"))
                     print(
                         "你是不是不知道怎么用的？那就让我来告诉你吧!!\n"
                         "这个函数是一个输出工具的集合，是由鱼鱼有几斤整理的\n"
@@ -88,13 +89,11 @@ def 帮助():
                         " (注意哦,分割线和日志都是可以和颜色叠加使用的)\n"
                         "---------------------\n"
                         "‘分割线’的语法是:\n"
-                        "logs.分割线(输出显示文字,s模式='项目名')\n"
+                        "logs.分割线(标题,文本,颜色选择)\n"
                         "‘日志’的语法是:\n"
-                        "logs.日志(输出显示文字)\n"
+                        "logs.日志(显示文字,颜色选择)\n"
                         "‘颜色’的语法是:\n"
-                        "logs.颜色(输出显示文字)\n"
-                        "示例（可以这种方法套）"
-                        "print(logs.颜色(logs.分割线('帮助文档',s模式='🦈Fishconsole'),色选='蓝色'))\n"
+                        "logs.颜色(输出显示文字,颜色选择)\n"
                         "---------------------\n"
                     )
 
@@ -300,7 +299,8 @@ def 帮助():
                     res=window.列表选择对话框("这相当于是我的一个代码仓库吧，我以后写的所有可以拿来用的小程序全都会放在这里（是不是很过分☕😉）", "tool玩具模块", [
                         "密码模块",
                         "网易云音乐模块",
-                        "排名模块"
+                        "排名模块",
+                        "文件存在性检测模块"
                     ])
                     for a in res:
                         if a=="密码模块":
@@ -321,10 +321,17 @@ def 帮助():
                                 "示例语法\n"
                                 "tool.网易云音乐(['歌单链接1'，'歌单链接2'])"
                             ,"网易云音乐模块","ok")
-                        if a=="网易云音乐模块":
+                        if a=="排名模块":
                             window.弹窗(
-                                "这个模块其实就是一个爬虫，爬的网易云的歌单里面的歌，最多只能爬一首歌单的前10首，vip的只能爬前几秒，下就下在根目录（我在搞事情哈哈）\n"
+                                "这个东西呢，就是对你输入的数据排个序，然后再按照你指定的那个序号来返回\n"
                                 "-----------------------------\n\n"
-                                "示例语法\n"
-                                "tool.网易云音乐(['歌单链接1'，'歌单链接2'])"
-                            ,"网易云音乐模块","ok")
+                                "语法就是\n"
+                                "tool.排名(数据源,第几个)"
+                            ,"排名模块","ok")
+                        if a=="文件存在性检测模块":
+                            window.弹窗(
+                                "就是找文件，他返回的是布尔值，有呢就是True，没有就是False，虽然没什么鸟用，但是总有人要用/dogedoge/咖啡\n"
+                                "-----------------------------\n\n"
+                                "语法就是\n"
+                                "tool.文件存在性检测(文件名)"
+                            ,"文件存在性检测模块","ok")
