@@ -467,9 +467,20 @@ def 网易云音乐(歌单链接列表):
                                 file.close()
 def 排名(数据源,第几个):
     第几个=int(第几个)
+    第几个=第几个-1
     a = 数据源
     for i in range(len(a)):
         for j in range(0, len(a) - 1):
             if a[j] > a[j + 1]:
                 a[j], a[j + 1] = a[j + 1], a[j]
     return a[第几个]
+
+
+def 文件存在性检测(文件名):
+    import os
+    if not os.path.exists(文件名):
+        file = False
+    else:
+        file = True
+    return file
+
